@@ -12,6 +12,7 @@
 #include "katze-throbber.h"
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 G_DEFINE_TYPE (KatzeThrobber, katze_throbber, GTK_TYPE_MISC)
 
@@ -131,7 +132,7 @@ katze_throbber_class_init (KatzeThrobberClass* class)
                                      g_param_spec_int (
                                      "icon-size",
                                      "Icon size",
-                                     "Symbolic size to use for the animation",
+                                     _("Symbolic size to use for the animation"),
                                      0, G_MAXINT, GTK_ICON_SIZE_MENU,
                                      flags));
 
@@ -140,7 +141,7 @@ katze_throbber_class_init (KatzeThrobberClass* class)
                                      g_param_spec_string (
                                      "icon-name",
                                      "Icon Name",
-                                     "The name of an icon containing animation frames",
+                                     _("The name of an icon containing animation frames"),
                                      "process-working",
                                      flags));
 
@@ -149,16 +150,16 @@ katze_throbber_class_init (KatzeThrobberClass* class)
                                      g_param_spec_object (
                                      "pixbuf",
                                      "Pixbuf",
-                                     "A GdkPixbuf containing animation frames",
+                                     _("A GdkPixbuf containing animation frames"),
                                      GDK_TYPE_PIXBUF,
-                                     flags));
+                                     G_PARAM_READWRITE));
 
     g_object_class_install_property (gobject_class,
                                      PROP_ANIMATED,
                                      g_param_spec_boolean (
                                      "animated",
                                      "Animated",
-                                     "Whether the throbber should be animated",
+                                     _("Whether the throbber should be animated"),
                                      FALSE,
                                      flags));
 
@@ -167,7 +168,7 @@ katze_throbber_class_init (KatzeThrobberClass* class)
                                      g_param_spec_string (
                                      "static-icon-name",
                                      "Static Icon Name",
-                                     "The name of an icon to be used as the static image",
+                                     _("The name of an icon to be used as the static image"),
                                      NULL,
                                      flags));
 
@@ -176,16 +177,16 @@ katze_throbber_class_init (KatzeThrobberClass* class)
                                      g_param_spec_object (
                                      "static-pixbuf",
                                      "Static Pixbuf",
-                                     "A GdkPixbuf to be used as the static image",
+                                     _("A GdkPixbuf to be used as the static image"),
                                      GDK_TYPE_PIXBUF,
-                                     flags));
+                                     G_PARAM_READWRITE));
 
     g_object_class_install_property (gobject_class,
                                      PROP_STATIC_STOCK_ID,
                                      g_param_spec_string (
                                      "static-stock-id",
                                      "Static Stock ID",
-                                     "The stock ID of an icon to be used as the static image",
+                                     _("The stock ID of an icon to be used as the static image"),
                                      NULL,
                                      flags));
 
@@ -204,7 +205,7 @@ katze_throbber_init (KatzeThrobber *throbber)
 }
 
 static void
-katze_throbber_dispose (GObject *object)
+katze_throbber_dispose (GObject* object)
 {
     KatzeThrobber* throbber = KATZE_THROBBER (object);
     KatzeThrobberPrivate* priv = throbber->priv;
@@ -216,17 +217,15 @@ katze_throbber_dispose (GObject *object)
 }
 
 static void
-katze_throbber_destroy (GtkObject *object)
+katze_throbber_destroy (GtkObject* object)
 {
     KatzeThrobber* throbber = KATZE_THROBBER (object);
     KatzeThrobberPrivate* priv = throbber->priv;
 
     katze_assign (priv->icon_name, NULL);
-    if (priv->pixbuf)
-        katze_object_assign (priv->pixbuf, NULL);
+    katze_object_assign (priv->pixbuf, NULL);
     katze_assign (priv->static_icon_name, NULL);
-    if (priv->static_pixbuf)
-        katze_object_assign (priv->static_pixbuf, NULL);
+    katze_object_assign (priv->static_pixbuf, NULL);
     katze_assign (priv->static_stock_id, NULL);
 
     GTK_OBJECT_CLASS (katze_throbber_parent_class)->destroy (object);
