@@ -11,20 +11,54 @@
 
 #include "webSearch.h"
 
-#include "global.h"
-#include "helpers.h"
 #include "search.h"
+
+#include "main.h"
 #include "sokoke.h"
 
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
-void update_searchEngine(guint index, CBrowser* browser)
+static GdkPixbuf*
+load_web_icon (const gchar* icon, GtkIconSize size, GtkWidget* widget)
+{
+    g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+    GdkPixbuf* pixbuf = NULL;
+    if (icon && *icon)
+    {
+        // TODO: We want to allow http as well, maybe also base64?
+        const gchar* icon_ready = g_str_has_prefix (icon, "file://")
+            ? &icon[7] : icon;
+        GtkStockItem stock_id;
+        if (gtk_stock_lookup (icon, &stock_id))
+            pixbuf = gtk_widget_render_icon (widget, icon_ready, size, NULL);
+        else
+        {
+            gint width, height;
+            gtk_icon_size_lookup (size, &width, &height);
+            if (gtk_widget_has_screen (widget))
+            {
+                GdkScreen* screen = gtk_widget_get_screen (widget);
+                pixbuf = gtk_icon_theme_load_icon (
+                    gtk_icon_theme_get_for_screen (screen), icon,
+                    MAX (width, height), GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
+            }
+        }
+        if (!pixbuf)
+            pixbuf = gdk_pixbuf_new_from_file_at_size (icon_ready, 16, 16, NULL);
+    }
+    if (!pixbuf)
+        pixbuf = gtk_widget_render_icon (widget, GTK_STOCK_FIND, size, NULL);
+    return pixbuf;
+}
+
+void update_searchEngine(guint index, GtkWidget* search)
 {
     guint n = g_list_length(searchEngines);
     // Display a default icon in case we have no engines
     if(!n)
-        sexy_icon_entry_set_icon(SEXY_ICON_ENTRY(browser->webSearch), SEXY_ICON_ENTRY_PRIMARY
+        sexy_icon_entry_set_icon(SEXY_ICON_ENTRY(search), SEXY_ICON_ENTRY_PRIMARY
          , GTK_IMAGE(gtk_image_new_from_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_MENU)));
     // Change the icon and default text according to the chosen engine
     else
@@ -34,24 +68,24 @@ void update_searchEngine(guint index, CBrowser* browser)
             index = 0;
         SearchEngine* engine = (SearchEngine*)g_list_nth_data(searchEngines, index);
         GdkPixbuf* pixbuf = load_web_icon(search_engine_get_icon(engine)
-         , GTK_ICON_SIZE_MENU, browser->navibar);
-        sexy_icon_entry_set_icon(SEXY_ICON_ENTRY(browser->webSearch)
+         , GTK_ICON_SIZE_MENU, search);
+        sexy_icon_entry_set_icon(SEXY_ICON_ENTRY(search)
          , SEXY_ICON_ENTRY_PRIMARY, GTK_IMAGE(gtk_image_new_from_pixbuf(pixbuf)));
         g_object_unref(pixbuf);
-        sokoke_entry_set_default_text(GTK_ENTRY(browser->webSearch)
+        sokoke_entry_set_default_text(GTK_ENTRY(search)
          , search_engine_get_short_name(engine));
-        config->searchEngine = index;
+        // config->searchEngine = index;
     }
 }
 
-void on_webSearch_engine_activate(GtkWidget* widget, CBrowser* browser)
+void on_webSearch_engine_activate(GtkWidget* widget, MidoriBrowser* browser)
 {
     guint index = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(widget), "engine"));
-    update_searchEngine(index, browser);
+    update_searchEngine(index, widget);
 }
 
 void on_webSearch_icon_released(GtkWidget* widget, SexyIconEntryPosition* pos
- , gint button, CBrowser* browser)
+ , gint button, MidoriBrowser* browser)
 {
     GtkWidget* menu = gtk_menu_new();
     guint n = g_list_length(searchEngines);
@@ -78,21 +112,22 @@ void on_webSearch_icon_released(GtkWidget* widget, SexyIconEntryPosition* pos
     }
     else
     {
-        menuitem = gtk_image_menu_item_new_with_label("Empty");
+        menuitem = gtk_image_menu_item_new_with_label(_("Empty"));
         gtk_widget_set_sensitive(menuitem, FALSE);
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
         gtk_widget_show(menuitem);
     }
 
-    menuitem = gtk_separator_menu_item_new();
+    /*menuitem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
     gtk_widget_show(menuitem);
     GtkAction* action = gtk_action_group_get_action(
      browser->actiongroup, "ManageSearchEngines");
     menuitem = gtk_action_create_menu_item(action);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
-    gtk_widget_show(menuitem);
-    sokoke_widget_popup(widget, GTK_MENU(menu), NULL);
+    gtk_widget_show(menuitem);*/
+    sokoke_widget_popup(widget, GTK_MENU(menu),
+		        NULL, SOKOKE_MENU_POSITION_LEFT);
 }
 
 static void on_webSearch_engines_render_icon(GtkTreeViewColumn* column
@@ -149,7 +184,7 @@ const gchar* STR_NON_NULL(const gchar* string)
 static void webSearch_editEngine_dialog_new(gboolean newEngine, CWebSearch* webSearch)
 {
     GtkWidget* dialog = gtk_dialog_new_with_buttons(
-        newEngine ? "Add search engine" : "Edit search engine"
+        newEngine ? _("Add search engine") : _("Edit search engine")
         , GTK_WINDOW(webSearch->window)
         , GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR
         , GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL
@@ -179,7 +214,7 @@ static void webSearch_editEngine_dialog_new(gboolean newEngine, CWebSearch* webS
 
     GtkWidget* hbox = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-    GtkWidget* label = gtk_label_new_with_mnemonic("_Name:");
+    GtkWidget* label = gtk_label_new_with_mnemonic(_("_Name:"));
     gtk_size_group_add_widget(sizegroup, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     GtkWidget* entry_shortName = gtk_entry_new();
@@ -195,7 +230,7 @@ static void webSearch_editEngine_dialog_new(gboolean newEngine, CWebSearch* webS
     
     hbox = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-    label = gtk_label_new_with_mnemonic("_Description:");
+    label = gtk_label_new_with_mnemonic(_("_Description:"));
     gtk_size_group_add_widget(sizegroup, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     GtkWidget* entry_description = gtk_entry_new();
@@ -209,7 +244,7 @@ static void webSearch_editEngine_dialog_new(gboolean newEngine, CWebSearch* webS
     
     hbox = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-    label = gtk_label_new_with_mnemonic("_Url:");
+    label = gtk_label_new_with_mnemonic(_("_URL:"));
     gtk_size_group_add_widget(sizegroup, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     GtkWidget* entry_url = gtk_entry_new();
@@ -223,7 +258,7 @@ static void webSearch_editEngine_dialog_new(gboolean newEngine, CWebSearch* webS
     
     hbox = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-    label = gtk_label_new_with_mnemonic("_Icon (name or file):");
+    label = gtk_label_new_with_mnemonic(_("_Icon (name or file):"));
     gtk_size_group_add_widget(sizegroup, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     GtkWidget* entry_icon = gtk_entry_new();
@@ -237,7 +272,7 @@ static void webSearch_editEngine_dialog_new(gboolean newEngine, CWebSearch* webS
     
     hbox = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-    label = gtk_label_new_with_mnemonic("_Keyword:");
+    label = gtk_label_new_with_mnemonic(_("_Keyword:"));
     gtk_size_group_add_widget(sizegroup, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     GtkWidget* entry_keyword = gtk_entry_new();
@@ -299,16 +334,16 @@ static void on_webSearch_remove(GtkWidget* widget, CWebSearch* webSearch)
     gtk_list_store_remove(GTK_LIST_STORE(liststore), &iter);
     search_engine_free(searchEngine);
     searchEngines = g_list_remove(searchEngines, searchEngine);
-    update_searchEngine(config->searchEngine, webSearch->browser);
+    //update_searchEngine(config->searchEngine, webSearch->browser);
     webSearch_toggle_edit_buttons(g_list_nth(searchEngines, 0) != NULL, webSearch);
     // FIXME: we want to allow undo of some kind
 }
 
-GtkWidget* webSearch_manageSearchEngines_dialog_new(CBrowser* browser)
+GtkWidget* webSearch_manageSearchEngines_dialog_new(MidoriBrowser* browser)
 {
-    const gchar* dialogTitle = "Manage search engines";
+    const gchar* dialogTitle = _("Manage search engines");
     GtkWidget* dialog = gtk_dialog_new_with_buttons(dialogTitle
-        , GTK_WINDOW(browser->window)
+        , GTK_WINDOW(browser)
         , GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR
         , GTK_STOCK_HELP
         , GTK_RESPONSE_HELP
@@ -394,7 +429,7 @@ GtkWidget* webSearch_manageSearchEngines_dialog_new(CBrowser* browser)
     return dialog;
 }
 
-gboolean on_webSearch_key_down(GtkWidget* widget, GdkEventKey* event, CBrowser* browser)
+gboolean on_webSearch_key_down(GtkWidget* widget, GdkEventKey* event, MidoriBrowser* browser)
 {
     GdkModifierType state = (GdkModifierType)0;
     gint x, y; gdk_window_get_pointer(NULL, &x, &y, &state);
@@ -403,39 +438,40 @@ gboolean on_webSearch_key_down(GtkWidget* widget, GdkEventKey* event, CBrowser*
     switch(event->keyval)
     {
     case GDK_Up:
-        update_searchEngine(config->searchEngine - 1, browser);
+        //update_searchEngine(config->searchEngine - 1, browser);
         return TRUE;
     case GDK_Down:
-        update_searchEngine(config->searchEngine + 1, browser);
+        //update_searchEngine(config->searchEngine + 1, browser);
         return TRUE;
     }
     return FALSE;
 }
 
-gboolean on_webSearch_scroll(GtkWidget* webView, GdkEventScroll* event, CBrowser* browser)
+gboolean on_webSearch_scroll(GtkWidget* webView, GdkEventScroll* event, MidoriBrowser* browser)
 {
     if(event->direction == GDK_SCROLL_DOWN)
-        update_searchEngine(config->searchEngine + 1, browser);
+        ;//update_searchEngine(config->searchEngine + 1, browser);
     else if(event->direction == GDK_SCROLL_UP)
-        update_searchEngine(config->searchEngine - 1, browser);
+        ;//update_searchEngine(config->searchEngine - 1, browser);
     return TRUE;
 }
 
-void on_webSearch_activate(GtkWidget* widget, CBrowser* browser)
+void on_webSearch_activate(GtkWidget* widget, MidoriBrowser* browser)
 {
     const gchar* keywords = gtk_entry_get_text(GTK_ENTRY(widget));
     gchar* url;
-    SearchEngine* searchEngine = (SearchEngine*)g_list_nth_data(searchEngines, config->searchEngine);
+    SearchEngine* searchEngine = (SearchEngine*)g_list_nth_data(searchEngines, 0/*config->searchEngine*/);
     if(searchEngine)
         url = searchEngine->url;
     else // The location search is our fallback
-     url = config->locationSearch;
+     url = "";//config->locationSearch;
     gchar* search;
     if(strstr(url, "%s"))
      search = g_strdup_printf(url, keywords);
     else
      search = g_strconcat(url, " ", keywords, NULL);
-    entry_completion_append(GTK_ENTRY(widget), keywords);
-    webkit_web_view_open(WEBKIT_WEB_VIEW(get_nth_webView(-1, browser)), search);
+    sokoke_entry_append_completion(GTK_ENTRY(widget), keywords);
+    GtkWidget* webView = midori_browser_get_current_web_view(browser);
+    webkit_web_view_open(WEBKIT_WEB_VIEW(webView), search);
     g_free(search);
 }
